;;;                 -*- Mode: Lisp; Package: BOOMS-APP -*-                  ;;;
;;; ----------------------------------------------------------------------- ;;;
;;; File:         bitmaps.lsp                                               ;;;
;;; Description:  BOOMS lisp bitmaps                                        ;;;
;;; Author:       Eli Barzilay - eli@cs.bgu.ac.il                           ;;;
;;; Date:         22-12-96                                                  ;;;
;;; Package:      BOOMS-APP                                                 ;;;
;;; ----------------------------------------------------------------------- ;;;

#|

This file is part of the BOOMS system:
+-----------------------------------------------------------------------------+
|                                                                             |
| /######   /#####   /#####  /##     /##  /#####                              |
| /##///## /##///## /##///## /###   /### /##///##                        /--- |
| /##  /## /##  /## /##  /## /#### /#### /##  ///          /------/     /     |
| /######/ /##  /## /##  /## /##/####/## //#####          /      /     /      |
| /##///## /##  /## /##  /## /##//##//##  /////##        /------/ __  /       |
| /##  /## /##  /## /##  /## /## /// /##      /##   __  /  __  / /  \/        |
| /##  /## /##  /## /##  /## /##     /## /##  /##  /  \/  /  \/  \__/         |
| /######/ //#####/ //#####/ /##     /## //#####/  \__/   \__/                |
| ///////   //////   //////  ///     ///  //////                              |
|                                                                             |
|                   Booms Object Oriented Music Structures.                   |
|Eli Barzilay:                                                   Maze is Life!|
+-----------------------------------------------------------------------------+

|#


;;;-------------------------------------------------------------------------;;;
;;;  B I T M A P S  file                                                    ;;;
;;;-------------------------------------------------------------------------;;;

(in-package :booms-app)


;;;-------------------------------------------------------------------------;;;
;;;  B I T M A P S  definitions                                             ;;;
;;;-------------------------------------------------------------------------;;;

;;; This is for the bitmap being stored in the compiled-file.
(defconstant +BOOMS-LOGO-BITMAP+
  (let ((already (member "logo.bmp" pc::*loaded-pixmaps*
                         :key #'first :test #'string-equal)))
    (if already
      (first already)
      (multiple-value-bind (bitmap texture) (load-pixmap "logo.bmp")
        (list "logo.bmp" bitmap texture)))))

(pushnew +booms-logo-bitmap+
         pc::*loaded-pixmaps* :key #'first :test #'string-equal)

(defconstant +BOOMS-BUTTON-TEXTURE+
  #S(texture-info
     width 16 height 16 bits-per-pixel 4
     x-device-units-per-m nil y-device-units-per-m nil colors
     #(#S(rgb red   0 green   0 blue   0)
       #S(rgb red 191 green   0 blue   0)
       #S(rgb red   0 green 191 blue   0)
       #S(rgb red 191 green 191 blue   0)
       #S(rgb red   0 green   0 blue 191)
       #S(rgb red 191 green   0 blue 191)
       #S(rgb red   0 green 191 blue 191)
       #S(rgb red 192 green 192 blue 192)
       #S(rgb red 128 green 128 blue 128)
       #S(rgb red 255 green   0 blue   0)
       #S(rgb red   0 green 255 blue   0)
       #S(rgb red 255 green 255 blue   0)
       #S(rgb red   0 green   0 blue 255)
       #S(rgb red 255 green   0 blue 255)
       #S(rgb red   0 green 255 blue 255)
       #S(rgb red 255 green 255 blue 255))))

(defmacro NEW-BMP (name arr)
  `(pushnew '(,name ,arr ,+booms-button-texture+)
            pc::*loaded-pixmaps* :key #'first :test #'string-equal))

(new-bmp "new"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  0  0  0  0  0  0  0  0  7  7  7  7  7  7)
              ( 7  7  0 15 15 15 15 15 15  0  0  7  7  7  7  7)
              ( 7  7  0 15 15 15 15 15 15  0 15  0  7  7  7  7)
              ( 7  7  0 15 15 15 15 15 15  0  0  0  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0 15 15 15 15 15 15 15 15 15  0  7  7  7)
              ( 7  7  0  0  0  0  0  0  0  0  0  0  0  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "open"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  0  0  0  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  0  7  7  7  0  7  0)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  0  0)
              ( 7  7  0  0  0  7  7  7  7  7  7  7  7  0  0  0)
              ( 7  0 15 15 15  0  0  0  0  0  0  0  7  7  7  7)
              ( 7  0 15 15 15 15 15 15 15 15 15  0  7  7  7  7)
              ( 7  0 15 15 15 15 15 15 15 15 15  0  7  7  7  7)
              ( 7  0 15 15 15 15  0  0  0  0  0  0  0  0  0  0)
              ( 7  0 15 15 15  0  8  8  8  8  8  8  8  8  8  0)
              ( 7  0 15 15  0  8  8  8  8  8  8  8  8  8  0  7)
              ( 7  0 15  0  8  8  8  8  8  8  8  8  8  0  7  7)
              ( 7  0  0  8  8  8  8  8  8  8  8  8  0  7  7  7)
              ( 7  0  0  0  0  0  0  0  0  0  0  0  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "save"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  0  0  0  0  0  0  0  0  0  0  0  0  0  0  7)
              ( 7  0  8  0 10 10 10 10 10 10 10 10  0 15  0  7)
              ( 7  0  8  0 10 10 10 10 10 10 10 10  0  0  0  7)
              ( 7  0  8  0 10 10 10 10 10 10 10 10  0  8  0  7)
              ( 7  0  8  0 10 10 10 10 10 10 10 10  0  8  0  7)
              ( 7  0  8  0 10 10 10 10 10 10 10 10  0  8  0  7)
              ( 7  0  8  0 10 10 10 10 10 10 10 10  0  8  0  7)
              ( 7  0  8  8  0  0  0  0  0  0  0  0  8  8  0  7)
              ( 7  0  8  8  8  8  8  8  8  8  8  8  8  8  0  7)
              ( 7  0  8  8  0  0  0  0  0  0  0  0  0  8  0  7)
              ( 7  0  8  8  0  0  0  0  0  0  8  8  0  8  0  7)
              ( 7  0  8  8  0  0  0  0  0  0  8  8  0  8  0  7)
              ( 7  0  8  8  0  0  0  0  0  0  8  8  0  8  0  7)
              ( 7  7  0  0  0  0  0  0  0  0  0  0  0  0  0  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "close"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  9  9  0  0  0  0  0  0  0  7  7  7  9  9  7)
              ( 7  9  0  9 15 15 15 15 15  0  0  7  9  0  9  7)
              ( 7  7  9  0  9 15 15 15 15  0 15  9  0  9  7  7)
              ( 7  7  0  9  0  9 15 15 15  0  9  0  9  7  7  7)
              ( 7  7  0 15  9  0  9 15 15  9  0  9  0  7  7  7)
              ( 7  7  0 15 15  9  0  9  9  0  9 15  0  7  7  7)
              ( 7  7  0 15 15 15  9  0  0  9 15 15  0  7  7  7)
              ( 7  7  0 15 15 15  9  0  0  9 15 15  0  7  7  7)
              ( 7  7  0 15 15  9  0  9  9  0  9 15  0  7  7  7)
              ( 7  7  0 15  9  0  9 15 15  9  0  9  0  7  7  7)
              ( 7  7  0  9  0  9 15 15 15 15  9  0  9  7  7  7)
              ( 7  7  9  0  9 15 15 15 15 15 15  9  0  9  7  7)
              ( 7  9  0  9  0  0  0  0  0  0  0  0  9  0  9  7)
              ( 7  9  9  7  7  7  7  7  7  7  7  7  7  9  9  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "cut"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  7  7  7  0  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  7  7  7  0  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  7  7  7  0  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  0  7  0  0  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  0  7  0  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  0  0  0  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  0  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  0  0  0  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  0  7  0  0  0  7  7  7  7  7)
              ( 7  7  7  7  0  0  0  7  0  7  7  0  7  7  7  7)
              ( 7  7  7  0  7  7  0  7  0  7  7  0  7  7  7  7)
              ( 7  7  7  0  7  7  0  7  0  7  7  0  7  7  7  7)
              ( 7  7  7  0  7  7  0  7  7  0  0  7  7  7  7  7)
              ( 7  7  7  7  0  0  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "copy"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  0  0  0  0  0  0  7  7  7  7  7  7  7  7  7)
              ( 7  0 15 15 15 15  0  0  7  7  7  7  7  7  7  7)
              ( 7  0 15 15 15 15  0 15  0  7  7  7  7  7  7  7)
              ( 7  0 15  0  0 15  0  0  0  0  0  0  7  7  7  7)
              ( 7  0 15 15 15 15  0 15 15 15 15  0  0  7  7  7)
              ( 7  0 15  0  0  0  0 15  0  0 15  0 15  0  7  7)
              ( 7  0 15 15 15 15  0 15 15 15 15  0  0  0  0  7)
              ( 7  0 15  0  0  0  0 15  0  0  0 15 15 15  0  7)
              ( 7  0 15 15 15 15  0 15 15 15 15 15 15 15  0  7)
              ( 7  0  0  0  0  0  0 15  0  0  0  0  0 15  0  7)
              ( 7  7  7  7  7  7  0 15 15 15 15 15 15 15  0  7)
              ( 7  7  7  7  7  7  0 15  0  0  0  0  0 15  0  7)
              ( 7  7  7  7  7  7  0 15 15 15 15 15 15 15  0  7)
              ( 7  7  7  7  7  7  0  0  0  0  0  0  0  0  0  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "paste"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  0  0  0  0  7  7  7  7  7  7  7)
              ( 7  7  0  0  0  0 15 15  0  0  0  0  0  7  7  7)
              ( 7  0 15 14  0 15  0  0 15  0 15 14 15  0  7  7)
              ( 7  0 14  0 15 15 15 15 15 15  0 15 14  0  7  7)
              ( 7  0 15  0  0  0  0  0  0  0  0 14 15  0  7  7)
              ( 7  0 14 15 14 15 14 15 14 15 14 15 14  0  7  7)
              ( 7  0 15 14 15 14  0  0  0  0  0  0  0  0  7  7)
              ( 7  0 14 15 14 15  0 15 15 15 15 15  0  0  7  7)
              ( 7  0 15 14 15 14  0 15 15 15 15 15  0 15  0  7)
              ( 7  0 14 15 14 15  0 15  0  0  0 15  0  0  0  7)
              ( 7  0 15 14 15 14  0 15 15 15 15 15 15 15  0  7)
              ( 7  0 14 15 14 15  0 15  0  0  0  0  0 15  0  7)
              ( 7  7  0  0  0  0  0 15 15 15 15 15 15 15  0  7)
              ( 7  7  7  7  7  7  0  0  0  0  0  0  0  0  0  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "edit-icon"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 9  9  9  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 9  0  9  0 11 11 11 11 11 11 11 11 11 11 11  0)
              ( 9  0  9  0 11  0  0  0 11 11 11 11 11 11 11  0)
              ( 9  9  9  0 11  0 11  0 11  0  0 11 11 11 11  0)
              ( 7  7  7  0 11  0 11  0 11 11 11 11 11 11 11  0)
              ( 7  7  7  0 11  0 11  0 11  0  0 11  0  0  0  0)
              ( 7  7  7  0 11  0 11  0 11 11 11 11 11 11 11  0)
              ( 7  7  7  0 11  0 11  0 11  0  0 11  0  0  0  0)
              ( 7  7  7  0 11  0  0  0 11 11 11 11 11 11 11  0)
              ( 7  7  7  0 11 11 11 11 11  0  0 11  0  0 11  0)
              ( 7  7  7  0 11  0 11  0 11  0  0 11  0  0 11  0)
              ( 7  7  7  0 11 11 11 11 11 11 11 11 11 11 11  0)
              ( 7  7  7  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "abstract"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  0  0  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  9  0  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  0  0  0  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  0  7  0  7  0  7  7  7  7  7  7  7)
              ( 7  7  7  0  7  7  0  7  7  0  7  7  7  7  7  7)
              ( 7  0  0  0  7  0  0  0  7  0  0  0  7  7  7  7)
              ( 7  0  9  0  7  0  9  0  7  0  9  0  7  7  7  7)
              ( 7  0  0  0  7  0  0  0  7  0  0  0  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  0  7  0  7  7  7  7  7  0  0  0  0  0  7)
              ( 7  7  0  7  7  0  7  7  7  7  0 10 10 10  0  7)
              ( 7  7  7  0  0  0  0  7  7  7  0 10 10 10  0  7)
              ( 7  7  7  7  7  0  7  7  7  7  0 10 10 10  0  7)
              ( 7  7  7  7  0  7  7  7  7  7  0  0  0  0  0  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "name-abstract"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  0  0  0  0  0  0  7  7  7  7  7)
              ( 7  7  7  0  0  0  0  0 14 14 14  0  0  7  7  7)
              ( 7  7  0 14 14  0  9  0 14 14 14 14 14  0  7  7)
              ( 7  0 14 14 14  0  0  0 14 14 14 14 14 14  0  7)
              ( 7  0 14 14  0 14  0 14  0 14 14 14 14 14  0  7)
              ( 0 14 14  0 14 14  0 14 14  0 14 14 14 14 14  0)
              ( 0  0  0  0 14  0  0  0 14  0  0  0 14 14 14  0)
              ( 0  0  9  0 14  0  9  0 14  0  9  0 14 14 14  0)
              ( 0  0  0  0 14  0  0  0 14  0  0  0 14 14 14  0)
              ( 0 14 14 14 14 14 14 14 14 14 14 14 14 14 14  0)
              ( 0 14  0 14  0 14 14 14 14 14  0  0  0  0  0  0)
              ( 7  0  0 14 14  0 14 14 14 14  0 10 10 10  0  7)
              ( 7  0 14  0  0  0  0 14 14 14  0 10 10 10  0  7)
              ( 7  7  0 14 14  0 14 14 14 14  0 10 10 10  0  7)
              ( 7  7  7  0  0 14 14 14 14 14  0  0  0  0  0  7)
              ( 7  7  7  7  7  0  0  0  0  0  0  7  7  7  7  7))))

(new-bmp "explode"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  0  0  0  0  0  7  0  0  0  7  7  7  7  7  7)
              ( 7  0 10 10 10  0  7  7  7  7  0  7  7  7  7  7)
              ( 7  0 10 10 10  0  7  7  0  7  0  7  0  7  7  7)
              ( 7  0 10 10 10  0  7  7  7  0  0  0  7  7  7  7)
              ( 7  0  0  0  0  0  7  7  7  7  0  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  0  0  0  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  0  9  0  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  0  0  0  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  0  7  0  7  0  7  7  7  7)
              ( 7  7  7  7  7  7  0  7  7  0  7  7  0  7  7  7)
              ( 7  7  7  7  0  0  0  7  0  0  0  7  0  0  0  7)
              ( 7  7  7  7  0  9  0  7  0  9  0  7  0  9  0  7)
              ( 7  7  7  7  0  0  0  7  0  0  0  7  0  0  0  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "named-copy"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  0  0  0  0  0  0  7  7  7  7  7)
              ( 7  0  0  0  0  0  0 14 14 14 14  0  0  7  7  7)
              ( 7  0 15 15 15 15  0  0 14 14 14 14 14  0  7  7)
              ( 7  0 15 15 15 15  0 15  0 14 14 14 14 14  0  7)
              ( 7  0 15  0  0 15  0  0  0  0  0  0 14 14  0  7)
              ( 0  0 15 15 15 15 15  0 15 15 15  0  0 14 14  0)
              ( 0  0 15  0  0  0  0  0 15  0 15  0 15  0 14  0)
              ( 0  0 15 15 15 15 15  0 15 15 15  0  0  0  0  0)
              ( 0  0 15  0  0  0  0  0 15  0  0 15 15 15  0  0)
              ( 0  0 15 15 15 15 15  0 15 15 15 15 15 15  0  0)
              ( 0  0  0  0  0  0  0  0 15  0  0  0  0 15  0  0)
              ( 7  0 14 14 14 14 14  0 15 15 15 15 15 15  0  7)
              ( 7  0 14 14 14 14 14  0 15  0  0  0  0 15  0  7)
              ( 7  7  0 14 14 14 14  0 15 15 15 15 15 15  0  7)
              ( 7  7  7  0  0 14 14  0  0  0  0  0  0  0  0  7)
              ( 7  7  7  7  7  0  0  0  0  0  0  7  7  7  7  7))))

(new-bmp "node-args"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  0  9  7  7  7 11  0  0 11  7  7  7  9  0  7)
              ( 7  0  9  7  7  7 11 11  0 11  7  7  7  9  0  7)
              ( 7  9  0  9  7  7 11  0 11 11  7  7  9  0  9  7)
              ( 7  9  0  9  7  7 11  0  0 11  7  7  9  0  9  7)
              ( 7  7  9  0  9  7 11 11  0 11  7  9  0  9  7  7)
              ( 7  7  9  0  9  7 11  0 11 11  7  9  0  9  7  7)
              ( 7  7  7  9  0  9 11  0  0 11  9  0  9  7  7  7)
              ( 7  7  7  9  0  9 11 11  0 11  9  0  9  7  7  7)
              ( 7  7  7  7  9  0  0  0  0  0  0  9  7  7  7  7)
              ( 7  7  7  7  9  0 10 10 10 10  0  9  7  7  7  7)
              ( 7  7  7  7  7  0 10 10 10 10  0  7  7  7  7  7)
              ( 7  7  7  7  7  0 10 10 10 10  0  7  7  7  7  7)
              ( 7  7  7  7  7  0 10 10 10 10  0  7  7  7  7  7)
              ( 7  7  7  7  7  0  0  0  0  0  0  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "grid"
         #2T((unsigned-byte 4)
             (( 7  0  7  7  7  0  7  7  7  0  7  7  7  7  7  7)
              ( 0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 0  0  0  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7)
              ( 7  0  7  7  7  0  7  7  7  0  7  7  7  0  7  7))))

(new-bmp "dialog-create"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 9  9  9  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 9  0  9  0 10 10 10 10 10 10 10 10 10 10 10  0)
              ( 9  0  9  0 10  0  0  0 10 10 10 10 10 10 10  0)
              ( 9  9  9  0 10  0 10  0 10  0  0 10 10 10 10  0)
              ( 7  7  7  0 10  0 10  0 10 10 10 10 10 10 10  0)
              ( 7  7  7  0 10  0 10  0 10  0  0 10  0  0  0  0)
              ( 7  7  7  0 10  0 10  0 10 10 10 10 10 10 10  0)
              ( 7  7  7  0 10  0 10  0 10  0  0 10  0  0  0  0)
              ( 7  7  7  0 10  0  0  0 10 10 10 10 10 10 10  0)
              ( 7  7  7  0 10 10 10 10 10  0  0 10  0  0 10  0)
              ( 7  7  7  0 10  0 10  0 10  0  0 10  0  0 10  0)
              ( 7  7  7  0 10 10 10 10 10 10 10 10 10 10 10  0)
              ( 7  7  7  0  0  0  0  0  0  0  0  0  0  0  0  0)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))

(new-bmp "refresh"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7 14  7  7  7  7  7  7  7  7)
              ( 7  9  7  7  7 11  7 14 14  7 11  7  7  7  9  7)
              ( 7  7 11  7  7 11  7 14 14  7 11  7  7 11  7  7)
              ( 7  7  7 11  7  7  7 14 14  7  7  7 11  7  7  7)
              ( 7  7  7  7 11  7  7 14  7  7  7 11  7  7  7  7)
              ( 7 11 11  7  7 11  9 14  7  9 11  7  7 11 11  7)
              ( 7  7  7  7  7  9 11  9  9 11  9  7  7  7  7  7)
              ( 7 10 10 10  7  7  9 11 11  9  7 10 10 10 10 10)
              (10 10 10 10 10  7  9 11 11  9  7  7 10 10 10  7)
              ( 7  7  7  7  7  9 11  9  9 11  9  7  7  7  7  7)
              ( 7 11 11  7  7 11  9  7 14  9 11  7  7 11 11  7)
              ( 7  7  7  7 11  7  7  7 14  7  7 11  7  7  7  7)
              ( 7  7  7 11  7  7  7 14 14  7  7  7 11  7  7  7)
              ( 7  7 11  7  7 11  7 14 14  7 11  7  7 11  7  7)
              ( 7  9  7  7  7 11  7 14 14  7 11  7  7  7  9  7)
              ( 7  7  7  7  7  7  7  7 14  7  7  7  7  7  7  7))))

(new-bmp "stop-music"
         #2T((unsigned-byte 4)
             (( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7)
              ( 7  9  9  7  7  7  7  7  0  7  7  7  7  9  9  7)
              ( 7  9  9  9  7  7  7  7  0  7  7  7  9  9  9  7)
              ( 7  7  9  9  9  7  7  7  0  7  7  9  9  9  7  7)
              ( 7  7  7  9  9  9  7  7  0  7  9  9  9  7  7  7)
              ( 7  7  7  7  9  9  9  7  0  9  9  9  7  7  7  7)
              ( 7  7  7  7  7  9  9  9  9  9  9  7  7  7  7  7)
              ( 7  7  7  7  7  7  9  9  9  9  7  7  7  7  7  7)
              ( 7  7  7  7  7  7  9  9  9  9  7  7  7  7  7  7)
              ( 7  7  7  7  7  9  9  9  9  9  9  7  7  7  7  7)
              ( 7  7  7  7  9  9  9  0  0  9  9  9  7  7  7  7)
              ( 7  7  7  9  9  9 10 10  0  7  9  9  9  7  7  7)
              ( 7  7  9  9  9 10 10 10  0  7  7  9  9  9  7  7)
              ( 7  9  9  9  0 10 10 10  0  7  7  7  9  9  9  7)
              ( 7  9  9  7  7  0  0  0  7  7  7  7  7  9  9  7)
              ( 7  7  7  7  7  7  7  7  7  7  7  7  7  7  7  7))))


;;;-------------------------------------------------------------------------;;;
;;;  D O N E !                                                              ;;;
;;;-------------------------------------------------------------------------;;;

(provide :BITMAPS)

