;;;                  -*- Mode: Lisp; Package: CL-USER -*-                   ;;;
;;; ----------------------------------------------------------------------- ;;;
;;; File:         packages.lsp                                              ;;;
;;; Description:  BOOMS package declarations                                ;;;
;;; Author:       Eli Barzilay - eli@cs.bgu.ac.il                           ;;;
;;; Date:         27-12-96                                                  ;;;
;;; Package:      CL-USER                                                   ;;;
;;; ----------------------------------------------------------------------- ;;;

#|

This file is part of the BOOMS system:
+-----------------------------------------------------------------------------+
|                                                                             |
| /######   /#####   /#####  /##     /##  /#####                              |
| /##///## /##///## /##///## /###   /### /##///##                        /--- |
| /##  /## /##  /## /##  /## /#### /#### /##  ///          /------/     /     |
| /######/ /##  /## /##  /## /##/####/## //#####          /      /     /      |
| /##///## /##  /## /##  /## /##//##//##  /////##        /------/ __  /       |
| /##  /## /##  /## /##  /## /## /// /##      /##   __  /  __  / /  \/        |
| /##  /## /##  /## /##  /## /##     /## /##  /##  /  \/  /  \/  \__/         |
| /######/ //#####/ //#####/ /##     /## //#####/  \__/   \__/                |
| ///////   //////   //////  ///     ///  //////                              |
|                                                                             |
|                   Booms Object Oriented Music Structures.                   |
|Eli Barzilay:                                                   Maze is Life!|
+-----------------------------------------------------------------------------+

|#


;;;-------------------------------------------------------------------------;;;
;;;  F I L E S  definitions                                                 ;;;
;;;-------------------------------------------------------------------------;;;

;;; The following forms should evaluate when loading.
(eval-when (:load-toplevel :execute)

;;; The BOOMS main package name.
(setf *BOOMS-PACKAGE* :booms-app)

;;; This is a list of BOOMS file names and corresponding packages.
(setf *BOOMS-FILES*
  '(("misc"     . :misc     )
    ("gr-misc"  . :misc     )
    ("midi-lib" . :midi-lib )
    ("geometry" . :geometry )
    ("bitmaps"  . :booms-app)
    ("network"  . :network  )
    ("constant" . :booms-app)
    ("boomsapp" . :booms-app)
    ("icons"    . :booms-app)
    ("iconedit" . :booms-app)
    ("coledit"  . :booms-app)
    ("leaves"   . :booms-app)
    ("boomsdoc" . :booms-app)
    ("saveload" . :booms-app)
    ("classpal" . :booms-app)
    ("shared-i" . :booms-app)
    ("abstract" . :booms-app)
    ("music"    . :music    )
    ("arith"    . :arith    )
    ("gcalc"    . :gcalc    )
    ("dialogs"  . :booms-app)))

) ; End of eval-when.


;;;-------------------------------------------------------------------------;;;
;;;  P A C K A G E S  definitions                                           ;;;
;;;-------------------------------------------------------------------------;;;

(in-package :cl-user)

(defpackage :MIDI-LIB
  (:use :common-lisp :allegro :c-types)
  (:export "PLAY-SOUND"
           "MIDI-OPEN-P" "MIDI-OPEN" "MIDI-CLOSE" "MIDI-RESET"
           "MIDI-START" "MIDI-STOP"
           "PLAY-NOTE-C"
           "GET-TIME" "PUT-EVENT" "MIDI-SEND"
           "START-PLAY" "END-PLAY" "PLAY-NOTE"
           "SET-VOLUME" "GET-VOLUME"
           "SET-TEMPO" "GET-TEMPO"))

(defpackage :GEOMETRY
  (:use :common-lisp :allegro :common-graphics)
  (:export "NBOX-TOP-LEFT" "NBOX-TOP-RIGHT"
           "NBOX-BOTTOM-RIGHT" "NBOX-BOTTOM-LEFT"
           "NNBOX-TOP-LEFT" "NNBOX-TOP-RIGHT"
           "NNBOX-BOTTOM-RIGHT" "NNBOX-BOTTOM-LEFT"
           "GET-NORMAL-BOX" "NORMALIZE-BOX"
           "BOXES-INTERSECT-P" "NBOXES-INTERSECT-P"
           "BOX-LINE-INTERSECT-P"))

(defpackage :MISC
  (:use :common-lisp :allegro :common-graphics :geometry)
  (:export "+NO-VALUE+" "MAPTREE" "MAKE-COPY" "SYMBOL-APPEND"
           "INSURE-SUPERCLASS" "PATHNAME-TO-STRING"
           "PUSHLAST" "PROGREV"
           ;; GR-MISC symbols
           "WITH-LOCK" "WITH-EVENTS-DISABLED" "WITH-CLIPPING"
           "WITH-BACKGROUND-MODE" "GET-CAPTION-HEIGHT"
           "GET-SCREEN-SIZE-X" "GET-SCREEN-SIZE-Y"
           "MENU-CLOSE" "OUTLINE-OPEN-ALL-VALUE" "COLOR-BOX"))

(defpackage :NETWORK
  (:use :common-lisp :allegro :misc)
  (:export "+NOT-CALCULATED+" "*NO-NETWORK-ERRORS*"
           "NODE" "NODEP" "SETNODE" "LEAF" "LEAFP" "SETLEAF"
           "DEFNODE"
           "TYPE-IN" "TYPE-OUT" "ARG-NAMES" "ARGS-NUM"
           "ARGUMENTS" "UPLINKS"
           "NO-ARGS-P" "FIXED-ARGS-P" "LIST-ARGS-P" "ARGUMENTS-FULL"
           "FORGET-VALUE"
           "GETARG0" "SETARG0" "DELARG0"
           "GETARG"  "SETARG"  "DELARG"
           "CHECK-ARG" "CHECK-ARGS"
           "DELETE-LINKS"
           "EVALUATE" "EVALUATED-P" "SELF"
           "COPY-NODES"
           "ABSTRACTION" "ABSTRACTIONP" "ROOT" "ROOT-NODE" "INTERNAL-NODES"
           "NODE/ARGSS" "HAVE-ABSTRACT-ARGS-P"
           "MAKE-ABSTRACTION" "EXPLODE-ABSTRACTION" "*ABSTRACTION-EXPLODING*"
           "IDENTITY" "LEAF-VALUE"))

;;; The primary package - it'll use all other packages automatically.
(defpackage :BOOMS-APP
  (:use :common-lisp :allegro :common-graphics
        :midi-lib :geometry :misc :network)
  (:export "BOOMS"
           ;; CONSTANT symbols
           "+WIN-ICON-SIZE+" "+ICON-MARGIN+" "+ICON-SIZE+"
           "+BORDER-LINE-WIDTH+"
           ;; BOOMSAPP symbols
           "*BOOMS-APP*" "*CALLED-PROGRAMMATICALLY*"
           "ACTIVE-DOCUMENT" "BOOMS-ICON" "REGISTER-TYPE" "SAY" "SAY!" "UNSAY"
           ;; ICONS symbols
           "ICON" "ICONP" "ICON-DOC"
           "ICON-FG-COLOR" "ICON-BG-COLOR" "ICON-SEL-COLOR"
           "ICON-INITIALIZE" "ICON-ICON" "ICON-WIDTH" "ICON-HEIGHT"
           "ICON-POS" "ICON-CENTER-POS" "ICON-SHOW" "ICON-HIDE" "ICON-RESHOW"
           "ICON-DRAW" "ICON-DRAW-ICON"
           "ICONIC-NODE" "ICON-DESCRIBE" "ICON-CLASS-TO-NAME" "SET-BOOMS-NAME"
           "ICON-DESCRIBE-NAME" "ICON-EVAL" "DEFICON"
           "ADD-ICON-MENU-ITEM" "MAKE-DEFAULT-ICON-MENU" "ICON-MENU"
           ;; ICONEDIT symbols
           "*ICON-EDIT-ICON*" "*ICON-EDIT-DIALOG-RUNNING*"
           "*ICON-EDIT-THE-TAB*" "*LAST-TAB-ID*" "ICON-TAB-IDS"
           "ICON-EDIT"
           "ADD-ICON-EDIT-TAB" "ADD-ICON-EDIT-TAB-WIDGET"
           "ICON-EDIT-SETUP-PAGE" "ICON-EDIT-DONE-PAGE"
           ;; COLEDIT
           "COLOR-UPDATE"
           ;; LEAVES symbols
           "ICONIC-LEAF" "DEFLEAF"
           "LEAF-INIT-VAL/PANE"
           "ICONIC-CONSTANT" "DEFCONSTLEAF"
           ;; BOOMSDOC symbols
           "DOC-FRAME" "DOCUMENT" "ICON-LIST" "SET-MODIFIED"
           "SELECTED-ICON-LIST" "DO-REDRAWS"
           "FRAME-TYPE" "PANE-TYPE"
           ;; SAVELOAD symbols
           "LOAD-SLOTS" "SAVABLE" "DOC-SAVE-DATA" "DOC-LOAD-DATA"
           ;; CLASSPAL symbols
           "ADD-NODE-CLASS"
           ;; SHARED-I symbols
           "ICONIC-IDENTITY" "ICONIC-IDENTITY-CLASS-NAME"
           ;; ABSTRACT symbols
           "ICONIC-ABSTRACT" "ICONIC-ABSTRACT-LEAF"
           "ICONIC-ABSTRACT-CLASS-NAME" "ICONIC-ABSTRACT-LEAF-CLASS-NAME"
           "ICONIC-NAMED-ABSTRACT" "ICONIC-NAMED-ABSTRACT-LEAF"
           "ICON-NAMED-ABSTRACTION-CLASS" "ICON-UNNAMED-ABSTRACTION-CLASS"
           "ADD-NODE-COPY-CLASS"
           ;; DIALOGS symbols
           "MY-POP-UP-DIALOG"
           "MY-POP-UP-MESSAGE-DIALOG" "MY-YES-OR-NO-P"
           "MY-ASK-USER-FOR-NEW-PATHNAME" "MY-ASK-USER-FOR-EXISTING-PATHNAME"
           "DIALOG-GET-VALUE" "DIALOG-GET-STRING" "DIALOG-GET-LIST-VALUE"))

(defpackage :MUSIC
  (:use :common-lisp :allegro :common-graphics :midi-lib :misc :network
        :booms-app)
  (:export "INITIALIZE-MUSIC-PACKAGE"))

(defpackage :ARITH
  (:use :common-lisp :allegro :common-graphics :misc :network :booms-app)
  (:export "INITIALIZE-ARITHMETIC-PACKAGE"))

(defpackage :GCALC
  (:use :common-lisp :allegro :common-graphics :misc :network :booms-app)
  (:export "INITIALIZE-GCALC-PACKAGE"))


;;; The following forms should evaluate when loading.
(eval-when (:load-toplevel :execute)

;;; Closing circular references.
(use-package '(:music :arith :gcalc) :booms-app)

;;; Import main function symbol to the cl-user package.
(import 'booms-app::booms :cl-user)

)

;;;-------------------------------------------------------------------------;;;
;;;  D O N E !                                                              ;;;
;;;-------------------------------------------------------------------------;;;

